=========================
An introduction to pyspec
=========================
   
pyspec is a package of modules to perform data analysis for x-ray scattering 
experiments. The basic modules are:

* pyspec.spec - moudle to read and parse spec data files
* pyspec.ccd - module to process CCD data from x-ray diffraction
  experiments
* pyspec.fit - module to perform least squares fitting 
* pyspec.fitfuncs - module of common fit functions (such as gaussian)
* pyspec.utils - common useful utilities (for example pickling)



